This extension resizes the slides to match the browser window height and
width. In other words, the slides are maximized to match the screen size.
The primary use case for this extension is for when you want to show your
slides in split screen, for example when demonstrating code in RStudio or
another window. To enable fit-to-screen, press Alt/Option + F during the
slideshow. To disable, reload the slides.